==> thirdparty-service-biz-1.0.45-20220111.060650-1-sources.jar: cn/com/duiba/constant/YangShiPinConfig.java <==
package cn.com.duiba.constant;

import com.google.common.collect.Sets;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.util.Set;

/**
 * @author haojiahong
 * @date 2020-10-09
 */
@Configuration
@ConfigurationProperties(prefix = "yangshipin")
public class YangShiPinConfig {

    private Set<Long> appIds = Sets.newHashSet(78211L);

    /**
     * 以下为判断是否冰雪卡用户接口参数
     */
    private String isIceCardUrl = "https://h5api.yangshipin.cn/web/is_ice_card";

    private String customerSupplyAppId = "2TtdvVQbvDiYsi8zo6WQ6rvoiBjJ";

    private String customerSupplyAppSecret = "3FyGYsE8y6F8SadE9Zg4v6eCKV45";

    private String randStr = "dfjlds";

    private String vAppId = "67988023";

    private String vSecret = "881bb45da6c2827a186f5a6983a2cd2a3b256e370a205acf";

    private String raw = "1";

    public Set<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(Set<Long> appIds) {
        this.appIds = appIds;
    }

    public String getIsIceCardUrl() {
        return isIceCardUrl;
    }

    public void setIsIceCardUrl(String isIceCardUrl) {
        this.isIceCardUrl = isIceCardUrl;
    }

    public String getCustomerSupplyAppId() {
        return customerSupplyAppId;
    }

    public void setCustomerSupplyAppId(String customerSupplyAppId) {
        this.customerSupplyAppId = customerSupplyAppId;
    }

    public String getCustomerSupplyAppSecret() {
        return customerSupplyAppSecret;
    }

    public void setCustomerSupplyAppSecret(String customerSupplyAppSecret) {
        this.customerSupplyAppSecret = customerSupplyAppSecret;
    }

    public String getRandStr() {
        return randStr;
    }

    public void setRandStr(String randStr) {
        this.randStr = randStr;
    }

    public String getvAppId() {
        return vAppId;
    }

    public void setvAppId(String vAppId) {
        this.vAppId = vAppId;
    }

    public String getvSecret() {
        return vSecret;
    }

    public void setvSecret(String vSecret) {
        this.vSecret = vSecret;
    }

    public String getRaw() {
        return raw;
    }

    public void setRaw(String raw) {
        this.raw = raw;
    }
}

==> thirdparty-service-biz-1.0.53-sources.jar: cn/com/duiba/constant/YangShiPinConfig.java <==
package cn.com.duiba.constant;

import com.google.common.collect.Sets;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.util.Set;

/**
 * @author haojiahong
 * @date 2020-10-09
 */
@Configuration
@ConfigurationProperties(prefix = "yangshipin")
public class YangShiPinConfig {

    private Set<Long> appIds = Sets.newHashSet(78211L);

    /**
     * 以下为判断是否冰雪卡用户接口参数
     */
    private String isIceCardUrl = "https://h5access.yangshipin.cn/web/is_ice_card";

    private String customerSupplyAppId = "4Z4v4UHXHtrbo9KDMnh5vebf6eAh";

    private String customerSupplyAppSecret = "67AFKPgbMRuNFogMgjmjDPyjVgg";

    private String randStr = "dfjlds";

    private String vAppId = "59306155";

    private String vSecret = "b42702bf7309a179d102f3d51b1add2fda0bc7ada64cb801";

    private String raw = "1";

    public Set<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(Set<Long> appIds) {
        this.appIds = appIds;
    }

    public String getIsIceCardUrl() {
        return isIceCardUrl;
    }

    public void setIsIceCardUrl(String isIceCardUrl) {
        this.isIceCardUrl = isIceCardUrl;
    }

    public String getCustomerSupplyAppId() {
        return customerSupplyAppId;
    }

    public void setCustomerSupplyAppId(String customerSupplyAppId) {
        this.customerSupplyAppId = customerSupplyAppId;
    }

    public String getCustomerSupplyAppSecret() {
        return customerSupplyAppSecret;
    }

    public void setCustomerSupplyAppSecret(String customerSupplyAppSecret) {
        this.customerSupplyAppSecret = customerSupplyAppSecret;
    }

    public String getRandStr() {
        return randStr;
    }

    public void setRandStr(String randStr) {
        this.randStr = randStr;
    }

    public String getvAppId() {
        return vAppId;
    }

    public void setvAppId(String vAppId) {
        this.vAppId = vAppId;
    }

    public String getvSecret() {
        return vSecret;
    }

    public void setvSecret(String vSecret) {
        this.vSecret = vSecret;
    }

    public String getRaw() {
        return raw;
    }

    public void setRaw(String raw) {
        this.raw = raw;
    }
}
